@@ -1,3 +1,4 @@
+#define VDSK_DEBUG /* FIXME */
 /*	$NetBSD$	*/
 /*	$OpenBSD: vdsk.c,v 1.46 2015/01/25 21:42:13 kettenis Exp $	*/
 /*
@@ -16,6 +17,7 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include <sys/kmem.h>
 #include <sys/param.h>
 #include <sys/buf.h>
 #include <sys/device.h>
@@ -247,6 +249,8 @@ FIXME openbsd
 	struct ldc_conn *lc;
 	int err, s;
 	int timeout;
+        vaddr_t va;
+        paddr_t pa;
 
 	sc->sc_bustag = ca->ca_bustag;
 	sc->sc_dmatag = ca->ca_dmatag;
@@ -284,73 +288,92 @@ FIXME openbsd
 		printf(", can't allocate tx queue\n");
 		return;
 	}
-printf("%s:%d\n", __FILE__, __LINE__);
 
 	lc->lc_rxq = ldc_queue_alloc(sc->sc_dmatag, VDSK_RX_ENTRIES);
 	if (lc->lc_rxq == NULL) {
 		printf(", can't allocate rx queue\n");
 		goto free_txqueue;
 	}
-printf("%s:%d\n", __FILE__, __LINE__);
 
-/* FIXME 2048 -> 16 */
-	sc->sc_lm = ldc_map_alloc(sc->sc_dmatag, 16);
+	sc->sc_lm = ldc_map_alloc(sc->sc_dmatag, 2048);
 	if (sc->sc_lm == NULL) {
 		printf(", can't allocate LDC mapping table\n");
 		goto free_rxqueue;
 	}
-printf("%s:%d\n", __FILE__, __LINE__);
+#if 0
+FIXME openbsd
 	err = hv_ldc_set_map_table(lc->lc_id,
 	    sc->sc_lm->lm_map->dm_segs[0].ds_addr, sc->sc_lm->lm_nentries);
+#else
+        va = (vaddr_t)sc->sc_lm->lm_slot;
+        pa = 0;
+	if (pmap_extract(pmap_kernel(), va, &pa) == FALSE)
+	  panic("pmap_extract failed %lx\n", va);
+	err = hv_ldc_set_map_table(lc->lc_id, pa, 2048);
+#endif
 	if (err != H_EOK) {
 		printf("hv_ldc_set_map_table %d\n", err);
-#if 0
-FIXME enable again when pa stuff works
 		goto free_map;
-#endif
 	}
-printf("%s:%d\n", __FILE__, __LINE__);
 
 	sc->sc_vd = vdsk_dring_alloc(sc->sc_dmatag, 32);
 	if (sc->sc_vd == NULL) {
 		printf(", can't allocate dring\n");
 		goto free_map;
 	}
-printf("%s:%d\n", __FILE__, __LINE__);
 	sc->sc_vsd = malloc(32 * sizeof(*sc->sc_vsd), M_DEVBUF, M_NOWAIT);
 	if (sc->sc_vsd == NULL) {
 		printf(", can't allocate software ring\n");
 		goto free_dring;
 	}
-printf("%s:%d\n", __FILE__, __LINE__);
 
+#if 0
+FIXME openbsd
 	sc->sc_lm->lm_slot[0].entry = sc->sc_vd->vd_map->dm_segs[0].ds_addr;
+#else
+        va = (vaddr_t)sc->sc_vd->vd_desc;
+        pa = 0;
+	if (pmap_extract(pmap_kernel(), va, &pa) == FALSE)
+	  panic("pmap_extract failed %lx\n", va);
+
+	sc->sc_lm->lm_slot[0].entry = pa;
+#endif
 	sc->sc_lm->lm_slot[0].entry &= LDC_MTE_RA_MASK;
 	sc->sc_lm->lm_slot[0].entry |= LDC_MTE_CPR | LDC_MTE_CPW;
 	sc->sc_lm->lm_slot[0].entry |= LDC_MTE_R | LDC_MTE_W;
 	sc->sc_lm->lm_next = 1;
 	sc->sc_lm->lm_count = 1;
-printf("%s:%d\n", __FILE__, __LINE__);
-
-	err = hv_ldc_tx_qconf(lc->lc_id,
+         va = lc->lc_txq->lq_va;
+	 pa = 0;
+	if (pmap_extract(pmap_kernel(), va, &pa) == FALSE)
+	  panic("pmap_extract failed %lx\n", va);
+#if 0
+FIXME openbsd
+	err = hv_ldc_tx_qconf(lc->lc_id, 
 	    lc->lc_txq->lq_map->dm_segs[0].ds_addr, lc->lc_txq->lq_nentries);
+#else
+        err = hv_ldc_tx_qconf(lc->lc_id, pa, lc->lc_txq->lq_nentries);
+#endif
 	if (err != H_EOK)
 		printf("hv_ldc_tx_qconf %d\n", err);
-printf("%s:%d\n", __FILE__, __LINE__);
-
+         va = (vaddr_t)lc->lc_rxq->lq_va;
+	pa = 0;
+	if (pmap_extract(pmap_kernel(), va, &pa) == FALSE)
+	  panic("pmap_extract failed %lx\n", va);
+#if 0
+FIXME openbsd
 	err = hv_ldc_rx_qconf(lc->lc_id,
 	    lc->lc_rxq->lq_map->dm_segs[0].ds_addr, lc->lc_rxq->lq_nentries);
+#else
+        err = hv_ldc_rx_qconf(lc->lc_id, pa, lc->lc_rxq->lq_nentries);
+#endif
 	if (err != H_EOK)
 		printf("hv_ldc_rx_qconf %d\n", err);
-printf("%s:%d\n", __FILE__, __LINE__);
 
 	cbus_intr_setenabled(sc->sc_bustag, ca->ca_tx_ino, INTR_ENABLED);
-printf("%s:%d\n", __FILE__, __LINE__);
 	cbus_intr_setenabled(sc->sc_bustag, ca->ca_rx_ino, INTR_ENABLED);
-printf("%s:%d\n", __FILE__, __LINE__);
 
 	ldc_send_vers(lc);
-printf("%s:%d\n", __FILE__, __LINE__);
 
 	printf("\n");
 
@@ -361,17 +384,17 @@ printf("%s:%d\n", __FILE__, __LINE__);
 	s = splbio();
 	timeout = 1000;
 	do {
-printf("%s:%d\n", __FILE__, __LINE__);
 		if (vdsk_rx_intr(sc) && sc->sc_vio_state == VIO_ESTABLISHED)
 			break;
 
 		delay(1000);
 	} while(--timeout > 0);
 	splx(s);
-printf("%s:%d\n", __FILE__, __LINE__);
 
-	if (sc->sc_vio_state != VIO_ESTABLISHED)
-		return;
+	if (sc->sc_vio_state != VIO_ESTABLISHED) {
+	  panic("vio not establshed: %d", sc->sc_vio_state); /* FIXME */
+	  return;
+	}
 
 #if 0
 FIXME openbsd
@@ -405,6 +428,7 @@ FIXME openbsd
 	saa.saa_sc_link = &sc->sc_link;
 	config_found(self, &saa, scsiprint);
 #endif
+
 	return;
 
 free_dring:
@@ -880,18 +904,19 @@ vdsk_dring_alloc(bus_dma_tag_t t, int nentries)
 	struct vdsk_dring *vd;
 	bus_size_t size;
 	vaddr_t va;
-	int nsegs;
 #if 0
-FIXME enable again when pa stuff works
-	int i;
+FIXME openbsd
+	int nsegs;
 #endif
+	int i;
 
 	vd = malloc(sizeof(struct vdsk_dring), M_DEVBUF, M_NOWAIT);
 	if (vd == NULL)
 		return NULL;
 
 	size = roundup(nentries * sizeof(struct vd_desc), PAGE_SIZE);
-
+#if 0
+FIXME openbsd
 	if (bus_dmamap_create(t, size, 1, size, 0,
 	    BUS_DMA_NOWAIT | BUS_DMA_ALLOCNOW, &vd->vd_map) != 0)
 		return (NULL);
@@ -907,24 +932,24 @@ FIXME enable again when pa stuff works
 	if (bus_dmamap_load(t, vd->vd_map, (void*)va, size, NULL,
 	    BUS_DMA_NOWAIT) != 0)
 		goto unmap;
-
+#else
+	va = (vaddr_t)kmem_zalloc(size, KM_NOSLEEP);
+#endif
 	vd->vd_desc = (struct vd_desc *)va;
 	vd->vd_nentries = nentries;
-#if 0
-FIXME enable again when pa stuff works
 	bzero(vd->vd_desc, nentries * sizeof(struct vd_desc));
 	for (i = 0; i < vd->vd_nentries; i++)
 		vd->vd_desc[i].hdr.dstate = VIO_DESC_FREE;
-#endif
 	return (vd);
-
+#if 0
+FIXME openbsd
 unmap:
 	bus_dmamem_unmap(t, (void*)va, size);
 free:
 	bus_dmamem_free(t, &vd->vd_seg, 1);
 destroy:
 	bus_dmamap_destroy(t, vd->vd_map);
-
+#endif
 	return (NULL);
 }
 
